@@ -1,23 +1,22 @@
-/* test file for mpc_strtoc.
+/* tstrtoc -- test file for mpc_strtoc.
 
-Copyright (C) INRIA, 2009, 2011
+Copyright (C) 2009, 2011 INRIA
 
-This file is part of the MPC Library.
+This file is part of GNU MPC.
 
-The MPC Library is free software; you can redistribute it and/or modify
-it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+GNU MPC is free software; you can redistribute it and/or modify it under
+the terms of the GNU Lesser General Public License as published by the
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPC Library is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
+GNU MPC is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for
+more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPC Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA 02111-1307, USA. */
+along with this program. If not, see http://www.gnu.org/licenses/ .
+*/
 
 #include <string.h>
 #include <stdlib.h>
@@ -93,8 +92,8 @@ check_file (const char* file_name)
       read_mpc_rounding_mode (fp, &rnd);
 
       /* 2. convert string at the same precision as the expected result */
-      mpfr_set_prec (MPC_RE (got), MPC_PREC_RE (expected));
-      mpfr_set_prec (MPC_IM (got), MPC_PREC_IM (expected));
+      mpfr_set_prec (mpc_realref (got), MPC_PREC_RE (expected));
+      mpfr_set_prec (mpc_imagref (got), MPC_PREC_IM (expected));
       inex = mpc_strtoc (got, str, &end, base, rnd);
 
       /* 3. compare this result with the expected one */
@@ -146,8 +145,8 @@ check_null (void)
   mpc_init2 (z, 53);
 
   inex = mpc_strtoc (z, NULL, &end, 10, MPC_RNDNN);
-  if (end != NULL || inex != -1 || mpfr_nan_p (MPC_RE (z)) == 0
-      || mpfr_nan_p (MPC_IM (z)) == 0)
+  if (end != NULL || inex != -1 || mpfr_nan_p (mpc_realref (z)) == 0
+      || mpfr_nan_p (mpc_imagref (z)) == 0)
     {
       printf ("Error: mpc_strtoc(z, NULL) with a NULL pointer should fail"
               " and the z value should be set to NaN +I*NaN\ngot ");
